==> vradi-swing-0.0.5-sources.jar: com/jurismarches/vradi/ui/helpers/XmlStreamHelper.java <==
package com.jurismarches.vradi.ui.helpers;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamConstants;
import javax.xml.stream.XMLStreamReader;

import org.apache.commons.io.IOUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.input.SAXBuilder;

import com.jurismarches.vradi.VradiConstants;
import com.jurismarches.vradi.services.VradiException;

/**
 * XmlStreamHelper.
 *
 * @author $Author: schorlet $
 * @version $Revision: 684 $ $Date: 2010-04-07 22:59:41 +0200 (mer., 07 avril 2010) $
 * @since 5 mars 2010 01:48:29
 */
public class XmlStreamHelper {
    private static final Log log = LogFactory.getLog(XmlStreamHelper.class);

    private XmlStreamHelper() {}
    
    public static void main(String[] args) throws VradiException {
        XmlStreamHelper helper = new XmlStreamHelper();
//        helper.getFirstElementXpp("http://s7.wm-s.fr/ARAO_V2/main.cgi?v=27");
//        helper.getFirstElementJDom("http://s7.wm-s.fr/ARAO_V2/main.cgi?v=27");

        helper.getFirstElementXpp("http://www.lequipe.fr/Xml/actu_rss.xml");
        helper.getFirstElementJDom("http://www.lequipe.fr/Xml/actu_rss.xml");
    }
    
    public static Element getFirstElement(String url) throws VradiException {
        return getFirstElementXpp(url);
    }

    private static Element getFirstElementJDom(String url) throws VradiException {
        try {
            long currentTimeMillis = System.currentTimeMillis();
                
            URL rssUrl = new URL(url);
            
            SAXBuilder builder = new SAXBuilder();
            Document document = builder.build(rssUrl);

            Element racine = document.getRootElement();
            log.debug("Root element name: " + racine.getName());
            
            Element firstElement = null;
            
            if (racine.getChild(VradiConstants.ITEM) != null) {
                firstElement = racine.getChild(VradiConstants.ITEM);
                
            } else if (racine.getChild(VradiConstants.ENTRY) != null) {
                firstElement = racine.getChild(VradiConstants.ENTRY);
                
            } else if (racine.getChild(VradiConstants.CHANNEL) != null) {
                Element element = racine.getChild(VradiConstants.CHANNEL);
                firstElement = element.getChild(VradiConstants.ITEM);
            }
            
            log.debug(System.currentTimeMillis() - currentTimeMillis);
            return firstElement;
            
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            throw new VradiException(e);
        }
    }
    
    private static Element getFirstElementXpp(String url) throws VradiException {
        InputStream openStream = null;
        try {
            long currentTimeMillis = System.currentTimeMillis();
            
            URL rssUrl = new URL(url);
            
            openStream = rssUrl.openStream();
            InputStreamReader streamReader = new InputStreamReader(openStream);
            BufferedReader bufferedReader = new BufferedReader(streamReader);

            XMLInputFactory inputFactory = XMLInputFactory.newInstance();
            XMLStreamReader reader = inputFactory.createXMLStreamReader(bufferedReader);
            
            Element firstElement = null;
            
            while (reader.hasNext()) {
                int type = reader.next();
                
                if (type == XMLStreamConstants.START_ELEMENT) {
                    String localName = reader.getLocalName();
                    
                    if (firstElement == null && (localName.equals(VradiConstants.ITEM) || localName.equals(VradiConstants.ENTRY))) {
                        firstElement = new Element(localName);
                        
                    } else if (firstElement != null) {
                        Element element = new Element(localName);
                        firstElement.addContent(element);
                    }
                    
                } else if (type == XMLStreamConstants.CHARACTERS || type == XMLStreamConstants.CDATA) {
                    if (firstElement != null && firstElement.getContentSize() > 0) {
                        int contentSize = firstElement.getContentSize();
                        Element content = (Element) firstElement.getContent(contentSize - 1);
                        content.setText(content.getTextTrim() + reader.getText());
                    }
                    
                } else if (type == XMLStreamConstants.END_ELEMENT) {
                    String localName = reader.getLocalName();
                    
                    if (firstElement != null && (localName.equals(VradiConstants.ITEM) || localName.equals(VradiConstants.ENTRY))) {
                        break;
                    }
                }
            }
            
            log.debug(System.currentTimeMillis() - currentTimeMillis);
            return firstElement;
            
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            throw new VradiException(e);
        } finally {
            IOUtils.closeQuietly(openStream);
        }
    }
    
    public static Set<String> getRSSFields(Element firstElement) {
        if (log.isDebugEnabled()) {
            log.debug("getRSSFields");
        }
        Set<String> result = new LinkedHashSet<String>();

        if (firstElement != null) {
            for (Element elt : (List<Element>) firstElement.getChildren()) {
                result.add(elt.getName());
            }
        }
        return result;
    }

    public static Map<String, String> getFirstElementValues(Element firstElement) {
        Map<String, String> result = new LinkedHashMap<String, String>();

        if (firstElement != null) {
            for (Element elt : (List<Element>) firstElement.getChildren()) {
                result.put(elt.getName(), elt.getText());
            }
        }
        return result;
    }

}

==> vradi-swing-0.1.0-sources.jar: com/jurismarches/vradi/ui/helpers/XmlStreamHelper.java <==
package com.jurismarches.vradi.ui.helpers;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamConstants;
import javax.xml.stream.XMLStreamReader;

import org.apache.commons.io.IOUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.input.SAXBuilder;

import com.jurismarches.vradi.VradiConstants;
import com.jurismarches.vradi.services.VradiException;

/**
 * XmlStreamHelper.
 *
 * @author $Author: chatellier $
 * @version $Revision: 1062 $ $Date: 2010-06-10 18:37:13 +0200 (jeu., 10 juin 2010) $
 * @since 5 mars 2010 01:48:29
 */
public class XmlStreamHelper {
    private static final Log log = LogFactory.getLog(XmlStreamHelper.class);
    
    public static Element getFirstElement(String url) throws VradiException {
        return getFirstElementXpp(url);
    }

    protected static Element getFirstElementJDom(String url) throws VradiException {
        try {
            long currentTimeMillis = System.currentTimeMillis();
                
            URL rssUrl = new URL(url);
            
            SAXBuilder builder = new SAXBuilder();
            Document document = builder.build(rssUrl);

            Element racine = document.getRootElement();
            log.debug("Root element name: " + racine.getName());
            
            Element firstElement = null;
            
            if (racine.getChild(VradiConstants.ITEM) != null) {
                firstElement = racine.getChild(VradiConstants.ITEM);
                
            } else if (racine.getChild(VradiConstants.ENTRY) != null) {
                firstElement = racine.getChild(VradiConstants.ENTRY);
                
            } else if (racine.getChild(VradiConstants.CHANNEL) != null) {
                Element element = racine.getChild(VradiConstants.CHANNEL);
                firstElement = element.getChild(VradiConstants.ITEM);
            }
            
            log.debug(System.currentTimeMillis() - currentTimeMillis);
            return firstElement;
            
        } catch (Exception eee) {
            log.error(eee.getMessage(), eee);
            throw new VradiException("Cant get first element", eee);
        }
    }
    
    protected static Element getFirstElementXpp(String url) throws VradiException {
        InputStream openStream = null;
        try {
            long currentTimeMillis = System.currentTimeMillis();
            
            URL rssUrl = new URL(url);
            
            openStream = rssUrl.openStream();
            InputStreamReader streamReader = new InputStreamReader(openStream);
            BufferedReader bufferedReader = new BufferedReader(streamReader);

            XMLInputFactory inputFactory = XMLInputFactory.newInstance();
            // don't check for DTD validity
            inputFactory.setProperty(XMLInputFactory.SUPPORT_DTD, "false");
            XMLStreamReader reader = inputFactory.createXMLStreamReader(bufferedReader);
            
            Element firstElement = null;
            
            while (reader.hasNext()) {
                int type = reader.next();
                
                if (type == XMLStreamConstants.START_ELEMENT) {
                    String localName = reader.getLocalName();
                    
                    if (firstElement == null && (localName.equals(VradiConstants.ITEM) || localName.equals(VradiConstants.ENTRY))) {
                        firstElement = new Element(localName);
                        
                    } else if (firstElement != null) {
                        Element element = new Element(localName);
                        firstElement.addContent(element);
                    }
                    
                } else if (type == XMLStreamConstants.CHARACTERS || type == XMLStreamConstants.CDATA) {
                    if (firstElement != null && firstElement.getContentSize() > 0) {
                        int contentSize = firstElement.getContentSize();
                        Element content = (Element) firstElement.getContent(contentSize - 1);
                        content.setText(content.getTextTrim() + reader.getText());
                    }
                    
                } else if (type == XMLStreamConstants.END_ELEMENT) {
                    String localName = reader.getLocalName();
                    
                    if (firstElement != null && (localName.equals(VradiConstants.ITEM) || localName.equals(VradiConstants.ENTRY))) {
                        break;
                    }
                }
            }
            
            log.debug(System.currentTimeMillis() - currentTimeMillis);
            return firstElement;
            
        } catch (Exception eee) {
            log.error(eee.getMessage(), eee);
            throw new VradiException("Cant get first element", eee);
        } finally {
            IOUtils.closeQuietly(openStream);
        }
    }
    
    public static Set<String> getRSSFields(Element firstElement) {
        if (log.isDebugEnabled()) {
            log.debug("getRSSFields");
        }
        Set<String> result = new LinkedHashSet<String>();

        if (firstElement != null) {
            for (Element elt : (List<Element>) firstElement.getChildren()) {
                result.add(elt.getName());
            }
        }
        return result;
    }

    public static Map<String, String> getFirstElementValues(Element firstElement) {
        Map<String, String> result = new LinkedHashMap<String, String>();

        if (firstElement != null) {
            for (Element elt : (List<Element>) firstElement.getChildren()) {
                result.put(elt.getName(), elt.getText());
            }
        }
        return result;
    }

}
